@@ -42,6 +42,9 @@ class AssetType(Enum):
     EVALUATIONRESULT = 'evaluationresult'
     MODEL = 'model'
     PROMPT = 'prompt'
+    AGENTBLUEPRINT = 'agentblueprint'
+    EVALUATOR = 'evaluator'
+    AGENTMANIFEST = 'agentmanifest'
 
 
 class ComponentType(Enum):
@@ -458,6 +461,11 @@ class Spec(Config):
         """Asset properties."""
         return self._yaml.get('properties', {})
 
+    @property
+    def system_metadata(self) -> Dict[str, str]:
+        """Asset system metadata."""
+        return self._yaml.get('system_metadata', {})
+
 
 class AssetPath:
     """Asset path."""
@@ -582,16 +590,7 @@ class AzureBlobstoreAssetPath(AssetPath):
             # If we fail pass through to the next approach
             pass
 
-        # Our second approach is to use the azure python SDK to view the properties
-        # of the container. If the container allows for anonymous access then we can
-        # return the URI "as-is".
-        #
-        # This approach is slower than the first approach, which is why we
-        # tried the simple HTTP request approach first.
-        #
-        # It also requires Azure Credentials to be configured which may or may
-        # not be present depending on the execution environment. If these credentials
-        # do not exist then fail gracefully, return the URI "as-is", and hope for the best.
+        # Generate a SAS token for the container and append it to the URI
         try:
             blob_service_client = BlobServiceClient(
                 account_url=self._account_uri,
@@ -599,18 +598,9 @@ class AzureBlobstoreAssetPath(AssetPath):
                     process_timeout=AzureBlobstoreAssetPath.AZURE_CLI_PROCESS_LOGIN_TIMEOUT
                 )
             )
-            container_client = blob_service_client.get_container_client(container=self._container_name)
 
-            # If the container allows for anonymous access then we can return the URI "as-is"
-            if container_client.get_container_properties().public_access is not None:
-                self._token = ""
-                return uri
-
-            # Our final approach is to generate a SAS token for the container and append
-            # it to the URI
             start_time = datetime.now(timezone.utc)
             expiry_time = start_time + token_expiration
-
             key = blob_service_client.get_user_delegation_key(start_time, expiry_time)
 
             self._token = generate_container_sas(
@@ -656,11 +646,11 @@ class AzureBlobstoreAssetPath(AssetPath):
             List[dict]: List of files and their sizes. Dicts have keys `name` and `size`.
         """
         container_client = self.get_container_client()
-        container_prefix = self._container_path + "/"
+        container_prefix = self._container_path + "/" if self._container_path else None
         blobs = container_client.list_blobs(name_starts_with=container_prefix)
 
         # Remove prefix if desired
-        starting_pos = len(container_prefix) if strip_container_prefix else 0
+        starting_pos = len(container_prefix) if container_prefix and strip_container_prefix else 0
         blobs = [{'name': blob.name[starting_pos:], 'size': blob.size} for blob in blobs]
         return blobs
 
@@ -801,7 +791,7 @@ class ModelConfig(Config):
             elif path_type == PathType.GIT.value:
                 self._path = GitAssetPath(branch=path['branch'], uri=path['uri'])
             elif path_type == PathType.LOCAL.value:
-                self._path = LocalAssetPath(local_path=path['uri'])
+                self._path = LocalAssetPath(uri=str(self._file_path / path['uri']))
             elif path_type == PathType.HTTP.value or path_type == PathType.FTP.value:
                 raise NotImplementedError("Support for HTTP and FTP is being added.")
         else:
