@@ -10,7 +10,7 @@ import sys
 import tempfile
 from collections import Counter
 from concurrent.futures import as_completed, ThreadPoolExecutor
-from datetime import timedelta
+from datetime import timedelta, datetime
 from pathlib import Path
 from ruamel.yaml import YAML
 from subprocess import run, PIPE, STDOUT
@@ -26,6 +26,8 @@ BUILD_STEP_TIMEOUT_SECONDS = 60 * 90
 SCAN_STEP_TIMEOUT_SECONDS = 60 * 20
 DEFAULT_STEP_TIMEOUT_SECONDS = 60 * 30
 TRIVY_TIMEOUT = "15m0s"
+TRIVY_VERSION = "v0.64.1-1"
+ORAS_VERSION = "v1.2.3-2"
 SUCCESS_COUNT = "success_count"
 FAILED_COUNT = "failed_count"
 COUNTERS = [SUCCESS_COUNT, FAILED_COUNT]
@@ -86,11 +88,15 @@ def create_acr_task(image_name: str,
     # Add vulnerability scanning step if requested
     if trivy_url is not None:
         if os is assets.Os.LINUX:
+            scan_cmd = (
+                f"mcr.microsoft.com/oss/v2/aquasecurity/trivy:{TRIVY_VERSION} "
+                f"-q --timeout {TRIVY_TIMEOUT} image --scanners vuln --ignore-unfixed "
+                f"$Registry/{image_name}"
+            )
             task['steps'].append({
                 'id': "scan",
                 'timeout': SCAN_STEP_TIMEOUT_SECONDS,
-                'cmd': f"aquasec/trivy -q --timeout {TRIVY_TIMEOUT} image --scanners vuln --ignore-unfixed "
-                       f"$Registry/{image_name}",
+                'cmd': scan_cmd,
                 'ignoreErrors': True,
                 'privileged': True
             })
@@ -103,6 +109,36 @@ def create_acr_task(image_name: str,
             'id': "push",
             'push': [f"$Registry/{image_name}"]
         })
+        # Add post-push vulnerability scan and SBOM attachment steps
+        post_scan_cmd = (
+            f"mcr.microsoft.com/oss/v2/aquasecurity/trivy:{TRIVY_VERSION} "
+            f"image --no-progress --format spdx-json --output sbom.json "
+            f"$Registry/{image_name} --timeout 15m0s"
+        )
+        task['steps'].append({
+            'id': "scan",
+            'timeout': 1200,  # 20 minute timeout for scanning
+            'cmd': post_scan_cmd,
+            'ignoreErrors': True,  # Don't fail build if scan fails
+            'privileged': True     # Required for some scan operations
+        })
+        # Compute current UTC timestamp in ISO 8601 format
+        timestamp = datetime.utcnow().isoformat() + "Z"
+        # Attach SBOM to the image
+        oras_cmd = (
+            f"mcr.microsoft.com/oss/v2/oras-project/oras:{ORAS_VERSION} attach $Registry/{image_name} "
+            f"--artifact-type application/vnd.microsoft.artifact.sbom+json "
+            f"--annotation 'org.opencontainers.image.created={timestamp}' "
+            f"--annotation 'org.opencontainers.image.title=SBOM generated by Trivy' "
+            f"--annotation 'org.opencontainers.image.description=Software Bill of Materials generated by Trivy' "
+            f"sbom.json:application/json"
+        )
+        task['steps'].append({
+            'id': "export-image",
+            'timeout': 300,  # 5 minute timeout for SBOM attachment
+            'cmd': oras_cmd,
+            'ignoreErrors': True  # Don't fail build if SBOM attachment fails
+        })
 
     # Write YAML file to disk
     with open(task_filename, "w") as f:
