@@ -5,9 +5,10 @@
 
 import difflib
 import filecmp
+import os
 import re
 import shutil
-from pathlib import Path
+from pathlib import Path, PurePath
 from ruamel.yaml import YAML
 from typing import List, Tuple, Union
 
@@ -93,6 +94,56 @@ def _are_files_equal_ignore_eol(file1: Path, file2: Path) -> bool:
                 return True
 
 
+def _resolve_from_file(value):
+    if os.path.isfile(value):
+        with open(value, 'r') as f:
+            content = f.read()
+            return (True, content)
+    else:
+        return (False, None)
+
+
+def resolve_from_file_for_asset(asset: assets.AssetConfig, value):
+    """Resolve the value from a file for an asset if it is a file, otherwise returns the value.
+
+    Args:
+        asset (AssetConfig): the asset to try and resolve the value for
+        value: value to try and resolve
+    """
+    if not is_file_relative_to_asset_path(asset, value):
+        return value
+
+    path_value = value if isinstance(value, Path) else Path(value)
+
+    if not path_value.is_relative_to(asset.file_path):
+        path_value = asset._append_to_file_path(path_value)
+
+    (is_resolved_from_file, resolved_value) = _resolve_from_file(path_value)
+
+    if is_resolved_from_file:
+        return resolved_value
+    else:
+        return value
+
+
+def is_file_relative_to_asset_path(asset: assets.AssetConfig, value):
+    """Check if the value from is a file with respect to the asset path.
+
+    Args:
+        asset (AssetConfig): the asset to try and resolve the value for
+        value: value to check
+    """
+    if not isinstance(value, str) and not isinstance(value, PurePath):
+        return False
+
+    path_value = value if isinstance(value, Path) else Path(value)
+
+    if not path_value.is_relative_to(asset.file_path):
+        path_value = asset._append_to_file_path(path_value)
+
+    return os.path.isfile(path_value)
+
+
 def copy_replace_dir(source: Path, dest: Path, paths: List[Path] = None):
     """Copy a directory tree, replacing any existing one.
 
