@@ -8,6 +8,7 @@ import argparse
 import json
 import re
 import sys
+import yaml
 from collections import defaultdict
 from pathlib import Path
 from ruamel.yaml import YAML
@@ -699,7 +700,13 @@ def validate_model_scenario(
     """
     error_count = 0
     min_sku = model.properties.get(min_sku_prop_name, "").strip()
-    recommended_skus = model.properties.get(recommended_skus_prop_name, "").strip()
+    recommended_skus_value = model.properties.get(recommended_skus_prop_name, None)
+    if isinstance(recommended_skus_value, str):
+        recommended_skus = [sku.strip() for sku in recommended_skus_value.split(",") if sku.strip()]
+    elif isinstance(recommended_skus_value, list):
+        recommended_skus = [str(sku).strip() for sku in recommended_skus_value if str(sku).strip()]
+    else:
+        recommended_skus = []
     compute_allowlists = set(model.tags.get(compute_allowlist_tags_name, []))
 
     if not min_sku:
@@ -714,10 +721,10 @@ def validate_model_scenario(
         _log_error(asset_file_name_with_path, f"{compute_allowlist_tags_name} is missing in model tags")
         error_count += 1
 
-    recommended_skus = set([sku.strip() for sku in recommended_skus.split(",")])
-    if (recommended_skus != compute_allowlists):
-        a_minus_b = recommended_skus - compute_allowlists
-        b_minus_a = compute_allowlists - recommended_skus
+    recommended_skus_set = set(recommended_skus)
+    if (recommended_skus_set != compute_allowlists):
+        a_minus_b = recommended_skus_set - compute_allowlists
+        b_minus_a = compute_allowlists - recommended_skus_set
         _log_error(
             asset_file_name_with_path,
             f"{recommended_skus_prop_name} and {compute_allowlist_tags_name} does not match for model.\n"
@@ -939,6 +946,32 @@ def validate_model_spec(asset_config: assets.AssetConfig) -> int:
     return error_count
 
 
+def validate_mlflow_model(asset_config: assets.AssetConfig) -> int:
+    """Validate if model is of type MLFlow.
+
+    Args:
+        asset_config (assets.AssetConfig): asset config for model spec
+    """
+    model_config = None
+
+    try:
+        load_model(asset_config.spec_with_path)
+        model_config: assets.ModelConfig = asset_config.extra_config_as_object()
+    except Exception:
+        logger.log_warning("Could not validate if model is of type MLFlow due to invalid spec or model config")
+        return
+
+    if model_config.type == assets.config.ModelType.MLFLOW:
+        logger.log_warning(f"{asset_config.name} is a model of type {model_config.type.value} "
+                           f"which is banned from the model catalog")
+
+        # Update mlflow_model_detected variable for Github Actions only
+        if "GITHUB_OUTPUT" in os.environ:
+            logger.print("Setting GITHUB_OUTPUT env variable for mlflow_model_detected=true")
+            with open(os.environ["GITHUB_OUTPUT"], "a") as f:
+                print("mlflow_model_detected=true", file=f)
+
+
 def get_validated_models_assets_map(model_validation_results_dir: str):
     """Return model assets map."""
     try:
@@ -970,7 +1003,8 @@ def validate_assets(input_dirs: List[Path],
                     check_categories: bool = False,
                     check_build_context: bool = False,
                     check_tests: bool = False,
-                    check_environment_version: bool = False) -> bool:
+                    check_environment_version: bool = False,
+                    added_files: List[Path] = None) -> bool:
     """Validate assets.
 
     Args:
@@ -985,6 +1019,7 @@ def validate_assets(input_dirs: List[Path],
         check_build_context (bool, optional): Whether to check environment build context. Defaults to False.
         check_tests (bool, optional): Whether to check test references. Defaults to False.
         check_environment_version (bool, optional): Whether to check environment version. Defaults to False.
+        added_files (List[Path], optional): List of added files, used for validating new assets. Defaults to None.
 
     Raises:
         ValidationException: If validation fails.
@@ -994,6 +1029,7 @@ def validate_assets(input_dirs: List[Path],
     """
     # Gather list of just changed assets, for later filtering
     changed_assets = util.find_asset_config_files(input_dirs, asset_config_filename, changed_files) if changed_files else None  # noqa: E501
+    added_assets = util.find_asset_config_files(input_dirs, asset_config_filename, added_files) if added_files else None  # noqa: E501
     validated_model_map = get_validated_models_assets_map(model_validation_results_dir)
 
     # Find assets under input dirs
@@ -1017,6 +1053,25 @@ def validate_assets(input_dirs: List[Path],
                 _log_warning(asset_config_path, e)
             continue
 
+        # Extract model variant info and defaultDeploymentTemplate from spec (not supported in SDK)
+        unsupported_fields = ["variantInfo", "defaultDeploymentTemplate"]
+        unsupported_fields_mapping = {}
+
+        if asset_config.type == assets.AssetType.MODEL:
+            with open(asset_config.spec_with_path, "r") as f:
+                spec_config = yaml.safe_load(f)
+
+                for field in unsupported_fields:
+                    if field in spec_config:
+                        logger.print(f"Found unsupported SDK field '{field}' in spec for asset {asset_config.name}")
+                        unsupported_fields_mapping[field] = spec_config.pop(field)
+
+            if unsupported_fields_mapping:
+                logger.print(f"Found unsupported fields in spec, popping out info and rewriting spec. "
+                             f"unsupported fields: {unsupported_fields_mapping}")
+                with open(asset_config.spec_with_path, "w") as f:
+                    yaml.dump(spec_config, f)
+
         # Populate dictionary of asset names to asset config paths
         asset_dirs[f"{asset_config.type.value} {asset_config.name}"].append(asset_config_path)
 
@@ -1061,6 +1116,12 @@ def validate_assets(input_dirs: List[Path],
             if check_tests:
                 error_count += validate_tests(asset_config)
 
+            # Validate if MLFlow model if new asset
+            if asset_config.type == assets.AssetType.MODEL:
+                if added_assets and asset_config_path in added_assets:
+                    logger.print(f"Validating type of new model: {asset_config.name}")
+                    validate_mlflow_model(asset_config)
+
             if asset_config.type == assets.AssetType.ENVIRONMENT:
                 # Validate Dockerfile
                 error_count += validate_dockerfile(asset_config.extra_config_as_object())
@@ -1122,6 +1183,12 @@ def validate_assets(input_dirs: List[Path],
                 _log_error(asset_config.spec_with_path, e)
                 error_count += 1
 
+        # Write unsupported fields back to spec
+        if unsupported_fields_mapping:
+            spec_config.update(unsupported_fields_mapping)
+            with open(asset_config.spec_with_path, "w") as f:
+                yaml.dump(spec_config, f)
+
     # Ensure unique assets
     for type_and_name, dirs in asset_dirs.items():
         if len(dirs) > 1:
@@ -1165,11 +1232,14 @@ if __name__ == '__main__':
                         help="Check test references")
     parser.add_argument("-e", "--check-environment-version", action="store_true",
                         help="Check environment version")
+    parser.add_argument("-d", "--added-files",
+                        help="Comma-separated list of added files, used to validate new assets")
     args = parser.parse_args()
 
     # Convert comma-separated values to lists
     input_dirs = [Path(d) for d in args.input_dirs.split(",")]
     changed_files = [Path(f) for f in args.changed_files.split(",")] if args.changed_files else []
+    added_files = [Path(f) for f in args.added_files.split(",")] if args.added_files else []
 
     # Share asset naming convention URL
     if args.check_names:
@@ -1190,6 +1260,7 @@ if __name__ == '__main__':
                               check_build_context=args.check_build_context,
                               model_validation_results_dir=args.model_validation_results_dir,
                               check_tests=args.check_tests,
-                              check_environment_version=args.check_environment_version)
+                              check_environment_version=args.check_environment_version,
+                              added_files=added_files)
     if not success:
         sys.exit(1)
